==> chronojump-1.7.0.tar.xz: chronojump-1.7.0/src/gui/chronopic.cs <==
/*
 * This file is part of ChronoJump
 *
 * Chronojump is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or   
 *    (at your option) any later version.
 *    
 * Chronojump is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the 
 *    GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Copyright (C) 2004-2017   Xavier de Blas <xaviblas@gmail.com> 
 */


using System;
using Gtk;
using Gdk;
using Glade;
using System.IO.Ports;
using Mono.Unix;
using System.Threading;
using System.IO; //"File" things
using System.Collections; //ArrayList
using System.Collections.Generic; //List

//gui stuff for the connection of one or two chronopics
public partial class ChronoJumpWindow
{
	//multi chronopic stuff
	List<ChronopicRegisterPort> crpMultiList;

	ChronopicRegisterPort crpDoing;
	bool connectAnother;
	int connectNum;
	enum connectingSequenceEnum { START, CONNECTINGREAL, FIRMWAREIFNEEDED, END }
	private static connectingSequenceEnum connectingSequence;

	private void chronopicConnectionSequenceInit(int numCPs)
	{
		connectNum = 1;
		if(numCPs == 1)
		{
			connectAnother = false;
			crpDoing = chronopicRegister.ConnectedOfType(ChronopicRegisterPort.Types.CONTACTS);
			//store a boolean in order to read info faster
			cp2016.StoredCanCaptureContacts = true;
		}
		else
		{ //2
			connectAnother = true;
			//will get two crps or null
			crpMultiList = chronopicRegister.GetTwoContactsConnected();
			//store a boolean in order to read info faster
			if(crpMultiList == null)
				return;

			crpDoing = crpMultiList[0];

			cp2016.StoredCanCaptureContacts = (crpMultiList.Count == 2);
		}
		connectingSequence = connectingSequenceEnum.START;
		chronopicConnectionSequenceDo();
	}

	private void chronopicConnectionSequenceDo()
	{
		//0 print sequence
		LogB.Information("SEQUENCE: " + connectingSequence.ToString());

		//1 check if need to end sequence or go to second chronopic
		if (connectingSequence == connectingSequenceEnum.END)
		{
			if(connectAnother)
			{
				System.Threading.Thread.Sleep(250);
				crpDoing = crpMultiList[1];
				connectingSequence = connectingSequenceEnum.START;
				connectAnother = false;
				connectNum = 2;
				chronopicConnectionSequenceDo();
				return;
			} else {
				button_activate_chronopics.Show();
				on_button_execute_test_accepted();
				return;
			}
		}

		//2 update sequence
		if(connectingSequence == connectingSequenceEnum.START)
		{
			if(cp2016.IsLastConnectedReal(crpDoing, connectNum)) {
				connectingSequence = connectingSequenceEnum.FIRMWAREIFNEEDED;
			} else {
				connectingSequence = connectingSequenceEnum.CONNECTINGREAL;
			}
			chronopicConnectionSequenceDo();
		}
		else if (connectingSequence == connectingSequenceEnum.CONNECTINGREAL)
		{
			callConnectContactsReal(crpDoing, connectNum);
			//this opens a thread and when end goes to chronopicConnectionSequenceDo again
		}
		else if (connectingSequence == connectingSequenceEnum.FIRMWAREIFNEEDED)
		{
			changeMultitestFirmwareIfNeeded(connectNum);
			//this will call chronopicConnectionSequenceDo if success
		}
	}

	private void callConnectContactsReal(ChronopicRegisterPort crp, int numCP)
	{
		cp2016.FakeButtonContactsRealDone.Clicked +=
			new EventHandler(on_connection_contacts_real_done);

		cp2016.ConnectContactsReal(app1, crp, numCP,
				Catalog.GetString("Please touch the platform or click Chronopic TEST button"));
	}

	private void on_connection_contacts_real_done (object o, EventArgs args)
	{
		cp2016.FakeButtonContactsRealDone.Clicked -=
			new EventHandler(on_connection_contacts_real_done);

		if(cp2016.SuccededConnectContactsRealThread)
		{
			LogB.Information("Success at Connecting real! (main GUI)");

			connectingSequence = connectingSequenceEnum.FIRMWAREIFNEEDED;
			chronopicConnectionSequenceDo();
		} else
			LogB.Warning("Failure at Connecting real! (main GUI)");
	}

	private void changeMultitestFirmwareIfNeeded(int cpCount)
	{
		//change multitest stuff
		threshold.UpdateAtDatabaseIfNeeded(getMenuItemMode());
		if(threshold.ShouldUpdateChronopicFirmware(cpCount))
		{
			bool ok = cp2016.ChangeMultitestFirmwarePre(threshold.GetT, cpCount);
			if(ok)
				threshold.ChronopicFirmwareUpdated(cpCount);
		}

		connectingSequence = connectingSequenceEnum.END;
		chronopicConnectionSequenceDo();
	}

}

==> chronojump-1.7.1.tar.xz: chronojump-1.7.1/src/gui/chronopic.cs <==
/*
 * This file is part of ChronoJump
 *
 * Chronojump is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or   
 *    (at your option) any later version.
 *    
 * Chronojump is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the 
 *    GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Copyright (C) 2004-2017   Xavier de Blas <xaviblas@gmail.com> 
 */


using System;
using Gtk;
using Gdk;
using Glade;
using System.IO.Ports;
using Mono.Unix;
using System.Threading;
using System.IO; //"File" things
using System.Collections; //ArrayList
using System.Collections.Generic; //List

//gui stuff for the connection of one or two chronopics
public partial class ChronoJumpWindow
{
	//multi chronopic stuff
	List<ChronopicRegisterPort> crpMultiList;

	ChronopicRegisterPort crpDoing;
	bool connectAnother;
	int connectNum;
	enum connectingSequenceEnum { START, CONNECTINGREAL, FIRMWAREIFNEEDED, END }
	private static connectingSequenceEnum connectingSequence;

	private void chronopicConnectionSequenceInit(int numCPs)
	{
		connectNum = 1;
		if(numCPs == 1)
		{
			connectAnother = false;
			crpDoing = chronopicRegister.ConnectedOfType(ChronopicRegisterPort.Types.CONTACTS);
			//store a boolean in order to read info faster
			cp2016.StoredCanCaptureContacts = true;
		}
		else
		{ //2
			connectAnother = true;
			//will get two crps or null
			crpMultiList = chronopicRegister.GetTwoContactsConnected();
			//store a boolean in order to read info faster
			if(crpMultiList == null)
				return;

			crpDoing = crpMultiList[0];

			cp2016.StoredCanCaptureContacts = (crpMultiList.Count == 2);
		}
		connectingSequence = connectingSequenceEnum.START;
		chronopicConnectionSequenceDo();
	}

	private void chronopicConnectionSequenceDo()
	{
		//0 print sequence
		LogB.Information("SEQUENCE: " + connectingSequence.ToString());

		//1 check if need to end sequence or go to second chronopic
		if (connectingSequence == connectingSequenceEnum.END)
		{
			if(connectAnother)
			{
				System.Threading.Thread.Sleep(250);
				crpDoing = crpMultiList[1];
				connectingSequence = connectingSequenceEnum.START;
				connectAnother = false;
				connectNum = 2;
				chronopicConnectionSequenceDo();
				return;
			} else {
				button_activate_chronopics.Show();
				on_button_execute_test_accepted();
				return;
			}
		}

		//2 update sequence
		if(connectingSequence == connectingSequenceEnum.START)
		{
			if(cp2016.IsLastConnectedReal(crpDoing, connectNum)) {
				connectingSequence = connectingSequenceEnum.FIRMWAREIFNEEDED;
			} else {
				connectingSequence = connectingSequenceEnum.CONNECTINGREAL;
			}
			chronopicConnectionSequenceDo();
		}
		else if (connectingSequence == connectingSequenceEnum.CONNECTINGREAL)
		{
			callConnectContactsReal(crpDoing, connectNum);
			//this opens a thread and when end goes to chronopicConnectionSequenceDo again
		}
		else if (connectingSequence == connectingSequenceEnum.FIRMWAREIFNEEDED)
		{
			changeMultitestFirmwareIfNeeded(connectNum);
			//this will call chronopicConnectionSequenceDo if success
		}
	}

	private void callConnectContactsReal(ChronopicRegisterPort crp, int numCP)
	{
		cp2016.FakeButtonContactsRealDone.Clicked +=
			new EventHandler(on_connection_contacts_real_done);

		cp2016.ConnectContactsReal(app1, crp, numCP,
				Catalog.GetString("Please touch the platform or click Chronopic TEST button"));
	}

	private void on_connection_contacts_real_done (object o, EventArgs args)
	{
		cp2016.FakeButtonContactsRealDone.Clicked -=
			new EventHandler(on_connection_contacts_real_done);

		if(cp2016.SuccededConnectContactsRealThread)
		{
			LogB.Information("Success at Connecting real! (main GUI)");

			connectingSequence = connectingSequenceEnum.FIRMWAREIFNEEDED;
			chronopicConnectionSequenceDo();
		} else
			LogB.Warning("Failure at Connecting real! (main GUI)");
	}

	private void changeMultitestFirmwareIfNeeded(int cpCount)
	{
		//change multitest stuff
		threshold.UpdateAtDatabaseIfNeeded(current_menuitem_mode);
		if(threshold.ShouldUpdateChronopicFirmware(cpCount))
		{
			bool ok = cp2016.ChangeMultitestFirmwarePre(threshold.GetT, cpCount);
			if(ok)
				threshold.ChronopicFirmwareUpdated(cpCount);
		}

		connectingSequence = connectingSequenceEnum.END;
		chronopicConnectionSequenceDo();
	}

}
